<%

Const vbDateSep = "-"
Const vbDateTimeSep = " "

'DateFormat -------------------------------------------------------------
' description:	produce a formatted date string from a WMI date/time
' parameters:	The format of 'wmiValue' is yyyymmddHHMMSS.mmmmmmsUUU
' returns:		a date in the fomat mmm d, yyyy. If any part the 'value' 
'				is not provided or cannot be interpreted, that portion 
'				will be replaced with today's year, month, etc.
Public Function wmiDateFormat(wmiValue)
	Dim year, month, day
	ParseWMIDate wmiValue, year, month, day
	
	Dim months(12)
	months(0) = "Jan"
	months(1) = "Feb"
	months(2) = "Mar"
	months(3) = "Apr"
	months(4) = "May"
	months(5) = "Jun"
	months(6) = "Jul"
	months(7) = "Aug"
	months(8) = "Sep"
	months(9) = "Oct"
	months(10) = "Nov"
	months(11) = "Dec"
 	wmiDateFormat = CStr(months(month-1)) + " " + CStr(day) + ", " + CStr(year)
End Function


'LocaleLongDateFormat ---------------------------------------------------
' description:	see DateFormat. The result is formatted according to the
'				long date format in the regional settings.
Private Function LocaleLongDateFormat(wmiValue)
	Dim year, month, day, date
	ParseWMIDate wmiValue, year, month, day
	date = DateSerial(year, month, day)
	LocaleLongDateFormat = FormatDateTime(date, vbLongDate)
End Function


'LocaleShortDateFormat --------------------------------------------------
' description:	see DateFormat. The result is formatted according to the
'				short date format in the regional settings.
Private Function LocaleShortDateFormat(wmiValue)
	Dim year, month, day, date
	ParseWMIDate wmiValue, year, month, day
	date = DateSerial(year, month, day)
	LocaleShortDateFormat = FormatDateTime(date, vbShortDate)
End Function


'TimeFormat -------------------------------------------------------------
' description:	produce a formatted time string from a WMI date/time. The 
'				format of 'wmiValue' is yyyymmddHHMMSS.mmmmmmsUUU.
' returns:		a time in the fomat HH:MM:SS. If any part the 'wmiValue' 
'				is not provided or cannot be interpreted, that portion 
'				will be replaced with 0.
Public Function TimeFormat(wmiValue)
	TimeFormat = ParseWMITime(wmiValue)
End Function


'LocaleLongTimeFormat ---------------------------------------------------
' description:	see TimeFormat. The result is formatted according to the
'				long time format in the regional settings.
Private Function LocaleLongTimeFormat(wmiValue)
	LocaleLongTimeFormat = FormatDateTime(ParseWMITime(wmiValue), vbLongTime)
End Function


'LocaleShortTimeFormat --------------------------------------------------
' description:	see TimeFormat. The result is formatted according to the
'				short time format in the regional settings.
Private Function LocaleShortTimeFormat(wmiValue)
	LocaleShortTimeFormat = FormatDateTime(ParseWMITime(wmiValue), vbShortTime)
End Function


'DateTimeFormat ---------------------------------------------------------
' description:	produce a formatted date/time string from a WMI date/time.
'				The format of 'wmiValue' is yyyymmddHHMMSS.mmmmmmsUUU
' returns:		a date/time in the fomat yyyy-mm-dd HH:MM:SS AM/PM. If any part 
'				the 'wmiValue' is not provided or cannot be interpreted, that 
'				portion will be replaced with today's year, month, etc.
Private Function DateTimeFormat(wmiValue)
	DateTimeFormat = DateFormat(wmiValue) + vbDateTimeSep + CStr(ParseWMITime(wmiValue))
End Function


'LocaleLongDateTimeFormat -----------------------------------------------
' description:	see DateTimeFormat. The result is formatted according to 
'				the long date and long time formats in the regional
'				settings.
Private Function LocaleLongDateTimeFormat(wmiValue)
	LocaleLongDateTimeFormat = LocaleLongDateFormat(wmiValue) + vbDateTimeSep + LocaleLongTimeFormat(wmiValue)
End Function


'LocaleShortDateTimeFormat ----------------------------------------------
' description:	see DateTimeFormat. The result is formatted according to 
'				the short date and short time formats in the regional
'				settings.
Private Function LocaleShortDateTimeFormat(wmiValue)
	LocaleShortDateTimeFormat = LocaleShortDateFormat(wmiValue) + vbDateTimeSep + LocaleShortTimeFormat(wmiValue)
End Function


'Internal / Helper functions --------------------------------------------
'------------------------------------------------------------------------

'ReadInt ----------------------------------------------------------------
' description:	helper function - reads the substring starting at 'begin'
'				of 'value' that is 'length' bytes long and returns it as
'				an int.
' parameters:	begin	- start position of sub string
'				length	- length of sub string
'				default - default integer value if an error occurs in
'						  reading the substring or converting it to an int
' returns:		the integer substring of 'value' beginning at 'begin'. If 
'				an error occurs (most likely the substring is
'				not numeric), 'default' is returned.
Private Function ReadInt(value, begin, length, default)
	On Error Resume Next
	ReadInt = CInt(Mid(value, begin, length))
	If 0 <> Err Then
		ReadInt = default
		Err.Clear
	End If
End Function


'ParseWMIDate -----------------------------------------------------------
' description:	Parses a date from WMI into a more readable form
' parameters:	The format of 'value' is yyyymmddHHMMSS.mmmmmmsUUU
' returns:		a Date. If any part the 'value' is not provided or 
'				cannot be interpreted, that portion will be replaced 
'				with today's year, month, etc.
Public Sub ParseWMIDate(value, year, month, day)
	Dim valueString
	valueString = CStr(value)
	year	= ReadInt(valueString, 1, 4, DatePart("yyyy", Date))
	month	= ReadInt(valueString, 5, 2, CInt(DatePart("m", Date)))
	day 	= ReadInt(valueString, 7, 2, CInt(DatePart("d", Date)))
End Sub

'ParseWMITime -----------------------------------------------------------
' description:	Parses a time from WMI into a more readable form
' parameters:	The format of 'value' is yyyymmddHHMMSS.mmmmmmsUUU
' returns:		a time in the fomat HH:MM:SS. If any part of the 'value' 
'				is not provided or cannot be interpreted, that portion 
'				will be replaced with 0 (12:00:00 AM).
Public Function ParseWMITime(value)
	Dim valueString, hour, minutes, seconds
	valueString = CStr(value)
	hour	= ReadInt(valueString, 9, 2, 0)
	minutes = ReadInt(valueString, 11, 2, 0)
	seconds = ReadInt(valueString, 13, 2, 0)
	
	ParseWMITime = TimeSerial(hour, minutes, seconds)
End Function
%>